# ifes_apt_tc_data_modeling

## Context:
`ifes_apt_tc_data_modeling` is a collection of Python modules for reading file formats
that are used in the research field of atom probe tomography and field ion microscopy.

The project combines all publicly available efforts of the atom probe research community
that individuals and [AMETEK/Cameca](https://github.com/CamecaAPT) as the leading technology partner in the field
have exchanged about how to work with different file formats used for atom probe research.

## Getting started:
Tutorials for how to get started as a user or software developer are available in the documentation.

## Acknowledgements:
Contributions of individuals made the consolidation of open-source software for parsing atom probe data possible. Here, [Daniel Haley](https://orcid.org/0000-0001-9308-2620), [Andrew London](https://orcid.org/0000-0001-6959-9849), [Baptiste Gault](https://orcid.org/0000-0002-4934-0458), David Reinhard (Cameca/AMETEK), Jim Payne (Cameca/AMETEK), [Andrew Breen](https://orcid.org/0000-0002-3600-5108), [Benjamin Caplins](https://orcid.org/0000-0002-4925-9537), [Peter Felfer](https://orcid.org/0000-0002-2338-1016), and [Mehrpad Monajem](https://orcid.org/0009-0002-6746-2835) are mentioned.

## Funding
The work on the ifes_apt_tc_data_modeling library is supported by the International Field Emission Society (IFES).
The library was written and is maintained by [Markus Kühbach](0000-0002-7117-5196). The work is funded by the
Deutsche Forschungsgemeinschaft (DFG, German Research Foundation) - 460197019 (FAIRmat).
